Index: trunk/src/org/openstreetmap/josm/gui/conflict/tags/CombinePrimitiveResolverDialog.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/conflict/tags/CombinePrimitiveResolverDialog.java	(revision 8973)
+++ trunk/src/org/openstreetmap/josm/gui/conflict/tags/CombinePrimitiveResolverDialog.java	(revision 8974)
@@ -79,6 +79,6 @@
  * merged to, see {@link #setTargetPrimitive(OsmPrimitive)}.
  *
  * After the dialog is closed use {@link #isCanceled()} to check whether the user canceled
  * the dialog. If it wasn't canceled you may build a collection of {@link Command} objects
  * which reflect the conflict resolution decisions the user made in the dialog:
  * see {@link #buildResolutionCommands()}
@@ -110,5 +110,5 @@
     private TagConflictResolver pnlTagConflictResolver;
     protected RelationMemberConflictResolver pnlRelationMemberConflictResolver;
-    private boolean canceled;
+    private boolean applied;
     private JPanel pnlButtons;
     protected transient OsmPrimitive targetPrimitive;
@@ -338,14 +338,14 @@
     }
 
-    protected void setCanceled(boolean canceled) {
-        this.canceled = canceled;
-    }
-
-    /**
-     * Determines if this dialog has been cancelled.
-     * @return true if this dialog has been cancelled, false otherwise.
-     */
-    public boolean isCanceled() {
-        return canceled;
+    protected void setApplied(boolean applied) {
+        this.applied = applied;
+    }
+
+    /**
+     * Determines if this dialog has been closed with "Apply".
+     * @return true if this dialog has been closed with "Apply", false otherwise.
+     */
+    public boolean isApplied() {
+        return applied;
     }
 
@@ -356,5 +356,5 @@
             new WindowGeometry(getClass().getName() + ".geometry", WindowGeometry.centerInWindow(Main.parent,
                     new Dimension(600, 400))).applySafe(this);
-            setCanceled(false);
+            setApplied(false);
             btnApply.requestFocusInWindow();
         } else if (isShowing()) { // Avoid IllegalComponentStateException like in #8775
@@ -375,5 +375,4 @@
         @Override
         public void actionPerformed(ActionEvent arg0) {
-            setCanceled(true);
             setVisible(false);
         }
@@ -391,4 +390,5 @@
         @Override
         public void actionPerformed(ActionEvent arg0) {
+            setApplied(true);
             setVisible(false);
             pnlTagConflictResolver.rememberPreferences();
@@ -515,5 +515,5 @@
             if (!dialog.isResolvedCompletely()) {
                 dialog.setVisible(true);
-                if (dialog.isCanceled()) {
+                if (!dialog.isApplied()) {
                     throw new UserCancelException();
                 }
@@ -79,6 +79,6 @@
  * merged to, see {@link #setTargetPrimitive(OsmPrimitive)}.
  *
- * After the dialog is closed use {@link #isCanceled()} to check whether the user canceled
- * the dialog. If it wasn't canceled you may build a collection of {@link Command} objects
+ * After the dialog is closed use {@link #isApplied()} to check whether the dialog has been
+ * applied. If it was applied you may build a collection of {@link Command} objects
  * which reflect the conflict resolution decisions the user made in the dialog:
  * see {@link #buildResolutionCommands()}
